package com.ruoyi.system.service.impl;


import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.ZxFj;
import com.ruoyi.system.domain.activity.ZxActivity;
import com.ruoyi.system.domain.bonus.ZxBonus;
import com.ruoyi.system.mapper.ZxFjMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ZxBonusMapper;
import com.ruoyi.system.service.IZxBonusService;

import java.util.ArrayList;
import java.util.List;

import static com.ruoyi.common.constant.CommonConstants.*;

/**
 * 政协履职加分Service业务层处理
 * 
 * @author boman
 * @date 2024-03-11
 */
@Service
public class ZxBonusServiceImpl implements IZxBonusService 
{
    @Autowired
    private ZxBonusMapper zxBonusMapper;

    @Autowired
    private ZxFjMapper zxFjMapper;

    /**
     * 查询政协履职加分
     * 
     * @param bonusId 政协履职加分主键
     * @return 政协履职加分
     */
    @Override
    public ZxBonus selectZxBonusByBonusId(Long bonusId)
    {
        return zxBonusMapper.selectZxBonusByBonusId(bonusId);
    }

    /**
     * 查询政协履职加分列表
     * 
     * @param zxBonus 政协履职加分
     * @return 政协履职加分
     */
    @Override
    public List<ZxBonus> selectZxBonusList(ZxBonus zxBonus)
    {
        return zxBonusMapper.selectZxBonusList(zxBonus);
    }

    /**
     * 新增政协履职加分
     * 
     * @param zxBonus 政协履职加分
     * @return 结果
     */
    @Override
    public int insertZxBonus(ZxBonus zxBonus)
    {
        //只能给自己账号加分
        zxBonus.setUserId(SecurityUtils.getUserId());
        zxBonus.setName(SecurityUtils.getUsername());
        zxBonus.setCreateTime(DateUtils.getNowDate());
        int rows = zxBonusMapper.insertZxBonus(zxBonus);
        insertZxFj(zxBonus);
        return rows;
    }

    /**
     * 修改政协履职加分
     * 
     * @param zxBonus 政协履职加分
     * @return 结果
     */
    @Override
    public int updateZxBonus(ZxBonus zxBonus)
    {
        zxBonus.setUpdateTime(DateUtils.getNowDate());
        ZxFj fj = new ZxFj();
        fj.setSourceId(zxBonus.getBonusId());
        fj.setType(SEV);
        //删除附件
        zxFjMapper.deleteZxFj(fj);
        insertZxFj(zxBonus);
        return zxBonusMapper.updateZxBonus(zxBonus);
    }

    /**
     * 批量删除政协履职加分
     * 
     * @param bonusIds 需要删除的政协履职加分主键
     * @return 结果
     */
    @Override
    public int deleteZxBonusByBonusIds(Long[] bonusIds)
    {
        return zxBonusMapper.deleteZxBonusByBonusIds(bonusIds);
    }

    /**
     * 删除政协履职加分信息
     * 
     * @param bonusId 政协履职加分主键
     * @return 结果
     */
    @Override
    public int deleteZxBonusByBonusId(Long bonusId)
    {
        return zxBonusMapper.deleteZxBonusByBonusId(bonusId);
    }

    /**
     * 新增加分附件信息
     */
    public void insertZxFj(ZxBonus zxBonus)
    {
        List<ZxFj> zxFjListFj = zxBonus.getZxFjList();
        Long bonusId = zxBonus.getBonusId();
        if (StringUtils.isNotNull(zxFjListFj))
        {
            List<ZxFj> list = new ArrayList<ZxFj>();
            for (ZxFj zxFj : zxFjListFj)
            {
                zxFj.setType(SEV);
                zxFj.setMainId(bonusId);
                zxFj.setSourceId(bonusId);
                list.add(zxFj);
            }
            if (list.size() > 0)
            {
                zxFjMapper.batchZxFj(list);
            }
        }
    }
}
