package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.Objects;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.investment.ZxInvestment;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ZxInvestmentMapper;
import com.ruoyi.system.service.IZxInvestmentService;

import static com.ruoyi.common.constant.CommonConstants.*;

/**
 * 政协委员招商引资Service业务层处理
 *
 * @author boman
 * @date 2024-03-27
 */
@Service
public class ZxInvestmentServiceImpl implements IZxInvestmentService {
    @Autowired
    private ZxInvestmentMapper zxInvestmentMapper;

    /**
     * 查询政协委员招商引资
     *
     * @param investmentId 政协委员招商引资主键
     * @return 政协委员招商引资
     */
    @Override
    public ZxInvestment selectZxInvestmentByInvestmentId(Long investmentId) {
        return zxInvestmentMapper.selectZxInvestmentByInvestmentId(investmentId);
    }

    /**
     * 查询政协委员招商引资列表
     *
     * @param zxInvestment 政协委员招商引资
     * @return 政协委员招商引资
     */
    @Override
    public List<ZxInvestment> selectZxInvestmentList(ZxInvestment zxInvestment) {
        return zxInvestmentMapper.selectZxInvestmentList(zxInvestment);
    }

    /**
     * 新增政协委员招商引资
     *
     * @param zxInvestment 政协委员招商引资
     * @return 结果
     */
    @Override
    public int insertZxInvestment(ZxInvestment zxInvestment) {
        zxInvestment.setUserId(SecurityUtils.getUserId());
        zxInvestment.setName(SecurityUtils.getUsername());
        zxInvestment.setCreateTime(DateUtils.getNowDate());
        zxInvestment.setPublishTime(DateUtils.getNowDate());
        return zxInvestmentMapper.insertZxInvestment(zxInvestment);
    }

    /**
     * 修改政协委员招商引资
     *
     * @param zxInvestment 政协委员招商引资
     * @return 结果
     */
    @Override
    public AjaxResult updateZxInvestment(ZxInvestment zxInvestment) {
        zxInvestment.setUpdateTime(DateUtils.getNowDate());
        zxInvestmentMapper.updateZxInvestment(zxInvestment);
        return AjaxResult.success();
    }

    /**
     * 批量删除政协委员招商引资
     *
     * @param investmentIds 需要删除的政协委员招商引资主键
     * @return 结果
     */
    @Override
    public int deleteZxInvestmentByInvestmentIds(Long[] investmentIds) {
        return zxInvestmentMapper.deleteZxInvestmentByInvestmentIds(investmentIds);
    }

    /**
     * 删除政协委员招商引资信息
     *
     * @param investmentId 政协委员招商引资主键
     * @return 结果
     */
    @Override
    public int deleteZxInvestmentByInvestmentId(Long investmentId) {
        return zxInvestmentMapper.deleteZxInvestmentByInvestmentId(investmentId);
    }
}
